==> kmr1_shorten-1.0.0.tar.gz: kmr1_shorten-1.0.0/kmr1_shorten/shorten.py <==
import sys
import argparse
from urllib.parse import urlparse, urlencode
from urllib.request import urlopen
import json

def is_valid_url(url):
    try:
        result = urlparse(url)
        return all([result.scheme, result.netloc])
    except ValueError:
        return False

def shorten_url(url, custom_characters=None):
    api_url = "https://api.kmr1.org/v1/"
    data = {"url": url}
    if custom_characters:
        data["custom_characters"] = custom_characters
    post_data = urlencode(data).encode("utf-8")
    try:
        with urlopen(api_url, data=post_data) as response:
            json_response = json.loads(response.read().decode("utf-8"))
            if "short_url" in json_response and "tracking_id" in json_response:
                print(f"Short_URL: {json_response['short_url']}")
                print(f"Tracking_ID: {json_response['tracking_id']}")
            elif "error" in json_response:
                print(f"エラー: {json_response['error']}")
            else:
                print("エラー: APIレスポンスに短縮URLまたはトラッキングIDが含まれていません。")
    except Exception as e:
        print(f"リクエストエラー: {e}")

def main():
    cmd_name = sys.argv[0].split('/')[-1].split('\\')[-1]
    if "kmr1_shorten" in cmd_name:
        usage = "kmr1_shorten <URL> [-c <カスタム文字列>]"
    elif "k1s" in cmd_name:
        usage = "k1s <URL> [-c <カスタム文字列>]"
    else:
        usage = "<command> <URL> [-c <カスタム文字列>]"

    parser = argparse.ArgumentParser(
        description="Kmr¹ APIを使用してURLを短縮します。Kmr¹API公式 https://api.kmr1.org/v1/use",
        usage=usage
    )
    parser.add_argument("url", help="短縮したいURL")
    parser.add_argument("-c", "--custom", help="カスタム文字列（オプション）")
    
    args = parser.parse_args()

    if not is_valid_url(args.url):
        print("エラー: 無効なURLです。")
        sys.exit(1)

    shorten_url(args.url, args.custom)

if __name__ == "__main__":
    main()

==> kmr1_shorten-1.0.2.tar.gz: kmr1_shorten-1.0.2/kmr1_shorten/shorten.py <==
import sys
import argparse
from urllib.parse import urlparse, urlencode
from urllib.request import urlopen
import json

def is_valid_url(url):
    try:
        result = urlparse(url)
        return all([result.scheme, result.netloc])
    except ValueError:
        return False

def shorten_url(url, custom_characters=None):
    api_url = "https://api.kmr1.org/v1/"
    data = {"url": url}
    if custom_characters:
        data["custom_characters"] = custom_characters
    post_data = urlencode(data).encode("utf-8")
    try:
        with urlopen(api_url, data=post_data) as response:
            json_response = json.loads(response.read().decode("utf-8"))
            if "short_url" in json_response and "tracking_id" in json_response:
                print(f"Short_URL: {json_response['short_url']}")
                print(f"Tracking_ID: {json_response['tracking_id']}")
            elif "error" in json_response:
                print(f"エラー: {json_response['error']}")
            else:
                print("エラー: APIレスポンスに短縮URLまたはトラッキングIDが含まれていません。")
    except Exception as e:
        print(f"リクエストエラー: {e}")

def main():
    cmd_name = sys.argv[0].split('/')[-1].split('\\')[-1]
    if "kmr1-shorten" in cmd_name:
        usage = "kmr1-shorten <URL> [-c <カスタム文字列>]"
    elif "k1s" in cmd_name:
        usage = "k1s <URL> [-c <カスタム文字列>]"
    else:
        usage = "<command> <URL> [-c <カスタム文字列>]"

    parser = argparse.ArgumentParser(
        description="Kmr¹ APIを使用してURLを短縮します。Kmr¹API公式ドキュメント https://api.kmr1.org/v1/use",
        usage=usage
    )
    parser.add_argument("url", help="短縮したいURL")
    parser.add_argument("-c", "--custom", help="カスタム文字列（オプション）")
    
    args = parser.parse_args()

    if not is_valid_url(args.url):
        print("エラー: 無効なURLです。")
        sys.exit(1)

    shorten_url(args.url, args.custom)

if __name__ == "__main__":
    main()
